# Copyright (C) 2009-2011, Ecole Polytechnique Federale de Lausanne (EPFL) and
# Hospital Center and University of Lausanne (UNIL-CHUV), Switzerland
# All rights reserved.
#
#  This software is distributed under the open-source license Modified BSD.

""" Traits configuration for CMA analysis """

try:
	import traits.api as traits
	from traits.ui.api import RangeEditor, EnumEditor, TextEditor, ListEditor, DirectoryEditor
except ImportError:
	try:
		import enthought.traits.api as traits
		from enthought.traits.ui.api import RangeEditor, EnumEditor, TextEditor, ListEditor, DirectoryEditor
	except ImportError:
		try:
			from traitsui.api import RangeEditor, EnumEditor, TextEditor, ListEditor, DirectoryEditor
		except ImportError:
			print('Error: could not import Enthought Traits module. Exiting...')

import os.path as op, os
import sys

from info import __version__


class PipelineConfiguration(traits.HasTraits):
       
    # project settings
    group1_dir = traits.Directory(exists=False)
    group2_dir = traits.Directory(exists=False)
    study_dir = traits.Directory(exists=False)
    multivariate_dirs = traits.List(traits.Directory,[],minlen=0)
    data_separ = traits.Enum([',',''],editor=EnumEditor(values={',':'comma(",")','':'spaces, tabs, newlines or carriage returns'}))
    masking = traits.Bool(False)
    mask_path = traits.File(exists=False)
    mask_separ = traits.Enum([',',''],editor=EnumEditor(values={',':'comma(",")','':'spaces, tabs, newlines or carriage returns'}))
    regress = traits.Bool(False)
    regression_file = traits.File(exists=False)
    regress_separ = traits.Enum([',',''],editor=EnumEditor(values={',':'comma(",")','':'spaces, tabs, newlines or carriage returns'}))

    # Multivariate analysis parameters
    n_perm = traits.Range(1000,None,1000, editor = RangeEditor(mode='text'))

    # Matrix file for relaxation only
    matrix_to_relax = traits.File(exists=False)
    
    # Relaxation parameters
    alternative = traits.Enum(['two.sided','greater','less'],editor = EnumEditor(values = {'two.sided':'Group1 != Group2','greater':'Group1 > Group2','less':'Group1 < Group2'}))
    decomposition_method = traits.Enum(['File','Automatic'])
    automatic_decompositions = traits.Enum(['Walktrap','leading.eigenvector','spinglass'])
    decomposition_file = traits.File(exists=False)
    decomposition_separ = traits.Enum([',',''],editor=EnumEditor(values={',':'comma(",")','':'spaces, tabs, newlines or carriage returns'}))
    RM = traits.Enum(["RMNC","RMIO","RMWC","AWA"])
    MCPProcedure = traits.Enum('bonferroni',["holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none", "gFER1", "gFER2", "gFDR1", "gFDR2"])
    test_type = traits.Enum(['parametric','non-parametric'])
    alpha1 = traits.Range(0.0,1.0,0.05,editor = RangeEditor(mode='text'))
    alpha2 = traits.Range(0.0,1.0,0.25,editor = RangeEditor(mode='text'))
    strong = traits.Range(1.0,None,1.0,editor = RangeEditor(mode='text'))
    summary_function = traits.Enum(['MeanEdgesWeights','mean'])
    paired = traits.Enum([False,True],editor = EnumEditor(values = {False:'Unpaired',True:'Paired'}))

    # Global analysis
    binarize = traits.Bool(True)
    is_weighted = traits.Bool(True)

    # Network measures
    mean_degree = traits.Bool(False)
    mean_betweenness = traits.Bool(False)
    mean_closeness = traits.Bool(False)
    mean_diameter = traits.Bool(False)
    global_efficiency = traits.Bool(False)
    #small_worldness = traits.Bool(False)

    # NBS analysis
    NBS_thresh = traits.Float(3)
    NBS_permutations = traits.Int(1000)
    NBS_tail = traits.Enum(['both','left','right'],editor=EnumEditor(values = {'both':'Group1 != Group2','left':'Group1 > Group2','right':'Group1 < Group2'}))

    # Node measures
    degree = traits.Bool(False)
    betweenness = traits.Bool(False)
    closeness = traits.Bool(False)
    diameter = traits.Bool(False)

    # Plot results
    plot_results = traits.Bool(False)
    node_labels = traits.Directory(exists=False)
    nodes_color = traits.Str("firebrick1")
    edges_color = traits.Str("yellow2")

    # Single subject
    single_matrix = traits.File(exists=False)
        
